==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/OpenIdConnectClientCredentialArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.OpenIdConnectClientCredentialArgs.builder
import com.pulumi.azurenative.app.kotlin.enums.ClientCredentialMethod
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The authentication client credentials of the custom Open ID Connect provider.
 * @property clientSecretSettingName The app setting that contains the client secret for the custom Open ID Connect provider.
 * @property method The method that should be used to authenticate the user.
 */
public data class OpenIdConnectClientCredentialArgs(
    public val clientSecretSettingName: Output<String>? = null,
    public val method: Output<ClientCredentialMethod>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.OpenIdConnectClientCredentialArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.OpenIdConnectClientCredentialArgs =
        com.pulumi.azurenative.app.inputs.OpenIdConnectClientCredentialArgs.builder()
            .clientSecretSettingName(clientSecretSettingName?.applyValue({ args0 -> args0 }))
            .method(method?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [OpenIdConnectClientCredentialArgs].
 */
@PulumiTagMarker
public class OpenIdConnectClientCredentialArgsBuilder internal constructor() {
    private var clientSecretSettingName: Output<String>? = null

    private var method: Output<ClientCredentialMethod>? = null

    /**
     * @param value The app setting that contains the client secret for the custom Open ID Connect provider.
     */
    @JvmName("tgtyqfooyqkkmqly")
    public suspend fun clientSecretSettingName(`value`: Output<String>) {
        this.clientSecretSettingName = value
    }

    /**
     * @param value The method that should be used to authenticate the user.
     */
    @JvmName("mmwypmbqnnibptgj")
    public suspend fun method(`value`: Output<ClientCredentialMethod>) {
        this.method = value
    }

    /**
     * @param value The app setting that contains the client secret for the custom Open ID Connect provider.
     */
    @JvmName("etsuylfpryjkbrxa")
    public suspend fun clientSecretSettingName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientSecretSettingName = mapped
    }

    /**
     * @param value The method that should be used to authenticate the user.
     */
    @JvmName("nacbvfljibljkkav")
    public suspend fun method(`value`: ClientCredentialMethod?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.method = mapped
    }

    internal fun build(): OpenIdConnectClientCredentialArgs = OpenIdConnectClientCredentialArgs(
        clientSecretSettingName = clientSecretSettingName,
        method = method,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/OpenIdConnectClientCredentialArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.OpenIdConnectClientCredentialArgs.builder
import com.pulumi.azurenative.app.kotlin.enums.ClientCredentialMethod
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The authentication client credentials of the custom Open ID Connect provider.
 * @property clientSecretSettingName The app setting that contains the client secret for the custom Open ID Connect provider.
 * @property method The method that should be used to authenticate the user.
 */
public data class OpenIdConnectClientCredentialArgs(
    public val clientSecretSettingName: Output<String>? = null,
    public val method: Output<ClientCredentialMethod>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.OpenIdConnectClientCredentialArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.OpenIdConnectClientCredentialArgs =
        com.pulumi.azurenative.app.inputs.OpenIdConnectClientCredentialArgs.builder()
            .clientSecretSettingName(clientSecretSettingName?.applyValue({ args0 -> args0 }))
            .method(method?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [OpenIdConnectClientCredentialArgs].
 */
@PulumiTagMarker
public class OpenIdConnectClientCredentialArgsBuilder internal constructor() {
    private var clientSecretSettingName: Output<String>? = null

    private var method: Output<ClientCredentialMethod>? = null

    /**
     * @param value The app setting that contains the client secret for the custom Open ID Connect provider.
     */
    @JvmName("cshowtswyuvvkodi")
    public suspend fun clientSecretSettingName(`value`: Output<String>) {
        this.clientSecretSettingName = value
    }

    /**
     * @param value The method that should be used to authenticate the user.
     */
    @JvmName("skrvmemxvrpooysa")
    public suspend fun method(`value`: Output<ClientCredentialMethod>) {
        this.method = value
    }

    /**
     * @param value The app setting that contains the client secret for the custom Open ID Connect provider.
     */
    @JvmName("wvbrxmpogtsdgtkf")
    public suspend fun clientSecretSettingName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientSecretSettingName = mapped
    }

    /**
     * @param value The method that should be used to authenticate the user.
     */
    @JvmName("rsdbunqkpqgtrmva")
    public suspend fun method(`value`: ClientCredentialMethod?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.method = mapped
    }

    internal fun build(): OpenIdConnectClientCredentialArgs = OpenIdConnectClientCredentialArgs(
        clientSecretSettingName = clientSecretSettingName,
        method = method,
    )
}
